/* Config.hh. Generated by CMake for ignition-transport8. */

#ifndef IGNITION_TRANSPORT_CONFIG_HH_
#define IGNITION_TRANSPORT_CONFIG_HH_

/* Version number */
#define IGNITION_TRANSPORT_MAJOR_VERSION 8
#define IGNITION_TRANSPORT_MINOR_VERSION 1
#define IGNITION_TRANSPORT_PATCH_VERSION 0

#define IGNITION_TRANSPORT_VERSION "8.1"
#define IGNITION_TRANSPORT_VERSION_FULL "8.1.0"

#define IGNITION_TRANSPORT_VERSION_NAMESPACE v8

#define IGNITION_TRANSPORT_VERSION_HEADER "Ignition transport, version 8.1.0\nCopyright (C) 2017 Open Source Robotics Foundation.\nReleased under the Apache 2.0 License.\n\n"

/* #undef BUILD_TYPE_PROFILE */
/* #undef BUILD_TYPE_DEBUG */
#define BUILD_TYPE_RELEASE 1

/* #undef HAVE_IFADDRS */
/* #undef UBUNTU_FOCAL */

#endif
